# ESG Capability Modeling Guidelines
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/esg-capability-modeling-guidelines#overview)
  * [Activating the ESG Capability Optional Feature](https://help.sap.com/docs/leanix/ea/esg-capability-modeling-guidelines#activating-the-esg-capability-optional-feature)
  * [Twin transitions & ESG: What are they, and how do they relate to Enterprise Architecture?](https://help.sap.com/docs/leanix/ea/esg-capability-modeling-guidelines#twin-transitions-&-esg:-what-are-they,-and-how-do-they-relate-to-enterprise-architecture?)
  * [Why Sustainable IT is relevant to organizations](https://help.sap.com/docs/leanix/ea/esg-capability-modeling-guidelines#why-sustainable-it-is-relevant-to-organizations)
  * [How to implement Sustainable IT Transformation with SAP LeanIX](https://help.sap.com/docs/leanix/ea/esg-capability-modeling-guidelines#how-to-implement-sustainable-it-transformation-with-sap-leanix)
  * [ESG Capability Fact Sheet Subtype](https://help.sap.com/docs/leanix/ea/esg-capability-modeling-guidelines#esg-capability-fact-sheet-subtype)
  * [Collaborate and collect data](https://help.sap.com/docs/leanix/ea/esg-capability-modeling-guidelines#collaborate-and-collect-data)
  * [Strategize with the ESG Capability Map](https://help.sap.com/docs/leanix/ea/esg-capability-modeling-guidelines#strategize-with-the-esg-capability-map)


View all
Learn how to implement sustainable IT transformation using the ESG capability optional feature.
